@@ -24,7 +24,7 @@ int32_t SPVM__Regex__compile(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_pattern = stack[1].oval;
   
   if (!obj_pattern) {
-    return env->die(env, stack, "The regex pattern must be defined", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The regex pattern must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   const char* pattern = env->get_chars(env, stack, obj_pattern);
@@ -40,13 +40,13 @@ int32_t SPVM__Regex__compile(SPVM_ENV* env, SPVM_VALUE* stack) {
   std::string error_arg = re2->error_arg();
   
   if (!re2->ok()) {
-    return env->die(env, stack, "The regex pattern %s can't be compiled. [Error]%s. [Fragment]%s", pattern, error.data(), error_arg.data(), FILE_NAME, __LINE__);
+    return env->die(env, stack, "The regex pattern %s can't be compiled. [Error]%s. [Fragment]%s", pattern, error.data(), error_arg.data(), __func__, FILE_NAME, __LINE__);
   }
   
-  void* obj_re2 = env->new_pointer_by_name(env, stack, "Regex::Re2", re2.release(), &e, FILE_NAME, __LINE__);
+  void* obj_re2 = env->new_pointer_by_name(env, stack, "Regex::Re2", re2.release(), &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
-  env->set_field_object_by_name(env, stack, obj_self, "re2", obj_re2, &e, FILE_NAME, __LINE__);
+  env->set_field_object_by_name(env, stack, obj_self, "re2", obj_re2, &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   return 0;
@@ -65,7 +65,7 @@ int32_t SPVM__Regex__match_forward(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_string = stack[1].oval;
   
   if (!obj_string) {
-    return env->die(env, stack, "The string must be defined", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The string must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   const char* string = env->get_chars(env, stack, obj_string);
@@ -74,7 +74,7 @@ int32_t SPVM__Regex__match_forward(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t* offset_ref = stack[2].iref;
   int32_t offset = *offset_ref;
   if (offset < 0) {
-    return env->die(env, stack, "The string offset must be greater than or equal to 0", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The string offset must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t length;
@@ -90,14 +90,14 @@ int32_t SPVM__Regex__match_forward(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   if (!(offset + length <= string_length)) {
-    return env->die(env, stack, "The offset + the length must be less than or equal to the length of the string", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The offset + the length must be less than or equal to the length of the string", __func__, FILE_NAME, __LINE__);
   }
   
-  void* obj_re2 = env->get_field_object_by_name(env, stack, obj_self, "re2", &e, FILE_NAME, __LINE__);
+  void* obj_re2 = env->get_field_object_by_name(env, stack, obj_self, "re2", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   if (!obj_re2) {
-    return env->die(env, stack, "The regex compililation is not yet performed", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The regex compililation is not yet performed", __func__, FILE_NAME, __LINE__);
   }
   
   RE2* re2 = (RE2*)env->get_pointer(env, stack, obj_re2);
@@ -115,17 +115,17 @@ int32_t SPVM__Regex__match_forward(SPVM_ENV* env, SPVM_VALUE* stack) {
     {
       void* obj_captures = env->new_object_array(env, stack, SPVM_NATIVE_C_BASIC_TYPE_ID_STRING, doller0_and_captures_length);
       if (!obj_captures) {
-        return env->die(env, stack, "Captures can't be created", FILE_NAME, __LINE__);; 
+        return env->die(env, stack, "Captures can't be created", __func__, FILE_NAME, __LINE__);; 
       }
       for (int32_t i = 0; i < doller0_and_captures_length; ++i) {
         if (i == 0) {
           int32_t match_start = (submatch[0].data() - string);
           int32_t match_length = submatch[0].length();
           
-          env->set_field_int_by_name(env, stack, obj_self, "match_start", match_start, &e, FILE_NAME, __LINE__);
+          env->set_field_int_by_name(env, stack, obj_self, "match_start", match_start, &e, __func__, FILE_NAME, __LINE__);
           if (e) { return e; }
           
-          env->set_field_int_by_name(env, stack, obj_self, "match_length", match_length, &e, FILE_NAME, __LINE__);
+          env->set_field_int_by_name(env, stack, obj_self, "match_length", match_length, &e, __func__, FILE_NAME, __LINE__);
           if (e) { return e; }
         }
         else {
@@ -133,7 +133,7 @@ int32_t SPVM__Regex__match_forward(SPVM_ENV* env, SPVM_VALUE* stack) {
           env->set_elem_object(env, stack, obj_captures, i, obj_capture);
         }
       }
-      env->set_field_object_by_name(env, stack, obj_self, "captures", obj_captures, &e, FILE_NAME, __LINE__);
+      env->set_field_object_by_name(env, stack, obj_self, "captures", obj_captures, &e, __func__, FILE_NAME, __LINE__);
       if (e) { return e; }
     }
     
@@ -155,7 +155,7 @@ int32_t SPVM__Regex__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_self = stack[0].oval;
 
-  void* obj_re2 = env->get_field_object_by_name(env, stack, obj_self, "re2", &e, FILE_NAME, __LINE__);
+  void* obj_re2 = env->get_field_object_by_name(env, stack, obj_self, "re2", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   if (obj_re2) {
